



### <a name="manual"></a> Line block

Inserts a horizontal line.

| Key       |      Description      | Default |
|:----------|:--------------------- | :---- |
| type      |  line                 |  
| dashes      |  (optional) render line with dashes, when provided as list: specifies dash width and space width     |  False <br/>[4, 3] |
| dashes      |  (optional) (true) / false OR list of two integers for custom dash (space, section)   |  
| width      |  (optional) width in cm     |  current document width |
| color      |  (optional) color of the line     |  black |
| thickness      |  (optional) thickness of the line in cm   |  0.5 |
| rounded      |  (optional) render line rounded    |  False

Example:
```YAML
- type     : line
```

Back to [Documentation](../../../README.md#block_basic)
